<template>
	<view class="check_add_index">
		<u-form
			ref="form"
			:model="formCheck"
			:rules="rulesCkeck"
			labelWidth="auto"
			labelPosition="left">
			<u-form-item
					label="姓名"
					prop="userIdValue"
					@click="changeUser()"
					borderBottom>
				<u-input
					v-model="formCheck.userIdValue"
					placeholder="请选择人员"
					disabled
					disabledColor="#FFFFFF"
					border="none">
				</u-input>
				<u-icon
					slot="right"
					name="arrow-right">
				</u-icon>
			</u-form-item>
			<u-form-item
					label="奖惩事项"
					prop="matter"
					borderBottom
					@click="changeRecord()">
				<u-input
					v-model="formCheck.matter"
					placeholder="参加消防知识培训"
					disabled
					disabledColor="#FFFFFF"
					border="none">
				</u-input>
				<u-icon
					slot="right"
					name="arrow-right">
				</u-icon>
			</u-form-item>
			<u-form-item
				label="标准"
				prop="encourageName"
				borderBottom>
				<u-input
					v-model="formCheck.encourageName"
					disabled="true"
					placeholder="请输入标准"
					border="none">
				</u-input>
			</u-form-item>
			<u-form-item
				label="类型"
				prop="matterType"
				borderBottom>
				<u-input
					v-model="formCheck.matterType"
					placeholder="请输入类型"
					disabled="true"
					border="none">
				</u-input>
			</u-form-item>
			<u-form-item
				label="分数"
				prop="integral"
				borderBottom>
				<u-input
					v-model="formCheck.integral"
					placeholder="请输入分数"
					disabled="true"
					border="none">
				</u-input>
			</u-form-item>
		</u-form>
		<view class="submit_bnt">
			<view class="btns_cancel">
				<u-button text="取消"  @click="cancelAdd()"></u-button>
			</view>
			<view class="btns_submit">
				<u-button type="primary" color="#1976FF" text="提交" @click="submitInsertForm()"></u-button>
			</view>
		</view>
		<u-picker 
			:show="showRecord" 
			:columns="recordColumns" 
			keyName="matter"
			@cancel="showRecord = false"
			@confirm="selectRecord">
		</u-picker>
		<u-picker
			:show="showUser" 
			:columns="userColumns" 
			keyName="realName"
			@cancel="showUser = false"
			@confirm="selectCompany">
		</u-picker>
	</view>
</template>

<script>
	import { throttle } from '../../plugins/public.js';
	import { basrUrl } from '@/api/http';
	export default{
		data(){
			return{
				showRecord: false, //奖惩事项
				showUser:false, //人的显隐
				recordColumns: [],
				userColumns:[],
				formCheck:{
					userId:'', //姓名
					encourageId:''
				},
				rulesCkeck: {
					userIdValue: [{
						required: true,
						message: '请选择人员',
						trigger: 'change'
					}],
					encourageName: [{
						required: true,
						message: '请输入标准',
						trigger: 'blur'
					}],
					matterType: [{
						required: true,
						message: '请输入类型',
						trigger: 'blur'
					}],
				}
			}
		},
		onLoad(option) {
			this.getUsersData()
			this.getAllmatters()
		},
		methods:{
			// 获取整改人信息
			async getUsersData() {
				const {data} = await this.$api.system.getAllUsersList({userType:2})
				this.userColumns = [data.list]
			},
			// 打开人选择
			 changeUser() {
				 this.showUser = true;
				 this.$set(this.formCheck, 'userId', '');
				 this.$set(this.formCheck, 'userIdValue','');
			 },
			// 确认选择人
			selectCompany({ value }) {
				 this.$set(this.formCheck, 'userId', value[0].userId);
				 this.$set(this.formCheck, 'userIdValue', value[0].realName);
				 this.showUser = false;
			},
			//提交按钮
			submitInsertForm: throttle(function() {
				this.$refs.form.validate().then((valid) => {
					if(valid) {
						const params = Object.assign({}, this.formCheck);
						params.matterType=this.formCheck.matterType==='加分'?1:this.formCheck.matterType==='减分'?2:''
						delete params.userIdValue
						this.$api.reboSystem.punishRecordAdd(params).then((res) => {
							if(res.success) {
								uni.$u.toast("提交成功！");
								uni.redirectTo({
									url: './punishRecord'
								});
							} else {
								uni.$u.toast(res.statusMsg);
							}
						})
					}
				})
			}, 3000),
			//取消添加跳转到上一页
			cancelAdd(){
				uni.redirectTo({
					url: './punishRecord'
				});
			},
			//获取奖惩事项下拉框
			async getAllmatters(){
				let params ={
					pageNum: 1,
					pageSize: 1000000000,
				}
				const {data}= await this.$api.reboSystem.punishMatterLists(params)
				this.recordColumns = [data.list]
			},
			// 打开奖惩事项选择
			 changeRecord() {
				 this.showRecord = true;
				 this.$set(this.formCheck, 'matter', '');
				 this.$set(this.formCheck, 'encourageName', '');
				 this.$set(this.formCheck, 'matterType', '');
				 this.$set(this.formCheck, 'integral', '');
			 },
			// 确认选择奖惩事项
			selectRecord({ value }) {
				console.log(value)
				 this.$set(this.formCheck, 'matter', value[0].matter);
				 this.$set(this.formCheck, 'encourageName', value[0].encourageName);
				 this.$set(this.formCheck, 'encourageId', value[0].encourageId);
				 this.$set(this.formCheck, 'matterType', value[0].matterType===1?'加分':value[0].matterType===2?'减分':'');
				 this.$set(this.formCheck, 'integral', value[0].integral);
				 this.showRecord = false;
			},
		}
	}
</script>

<style lang="scss" scoped>
	.check_add_index{
		background-color: #FFFFFF;
		padding: 0 15px;
		position: relative;
		height: 100vh;
		overflow: hidden;
	}
	.submit_bnt {
		position: absolute;
		bottom: 5%;
		width: calc(100% - 30px);
		display: flex;
		justify-content: space-between;
		.btns_cancel{
			width: 50%;
			margin-right: 10px;
		}
		.btns_submit{
			width: 50%;
		}
	}
	::v-deep .u-input__content__field-wrapper__field {
		text-align: right !important;
	}
	::v-deep .u-form-item{
		padding: 0 10px;
		background-color: #FFFFFF;
		line-height: 40px;
		border-radius: 4px;
	}
	::v-deep .u-input{
		background-color: transparent!important;
	}
</style>